<?php
$lang['error_insufficientparams'] = 'Param&egrave;tres insuffisant';
$lang['column_delimiter'] = 'Import file column delimiter';
$lang['import_completed'] = 'Importation termin&eacute;';
$lang['num_imported'] = 'Nombre d&#039;&eacute;v&egrave;nements cr&eacute;&eacute;s: %d';
$lang['import_lines'] = 'Nombre de lignes trait&eacute;es du fichier: %d';
$lang['errors'] = 'Erreurs';
$lang['error_csvfirstlineinvalidfield'] = 'Champs: %s non reconnu, et n&#039;est pas un champs personnalis&eacute;.';
$lang['info_csv_format'] = '<h4>CSV File Format Information.</h4>
<ul>
  <li>General Information:
   <ul>
     <li>The file must be an ASCII file with unix, dos, or (hopefully) mac line endings.</li>
     <li>Comments start with // any characters after this on a line will be ignored (including within quotes.</li>
     <li>Empty lines are ignore.d</li>
     <li>Fields are delimited with a , however a , can be used as a value within a field if the field is delimited by double quotes.</li>
     <li>Rows are delimited by newline chars (as above).</li>
   </ul>
  </li>
  <li>The Field Map:
   <ul>
    <li>The first line defines the order of the fields, and what &quot;custom fields&quot; are defined in the file. Data can start on the second non-empty line, or after.</li>
    <li>Theres are the required fields: start time, end time, title, summary, and description.  Without defining these fields in the header the import will not proceed.  Required field names are not case sensitive.</li>
    <li>There is one optional column:: &quot;category&quot;.  If specified it can contain a ; separated list of category names that the event will belong to.</li>
   </ul>
  </li>
  <li>The Data Rows:
   <ul>
    <li>The start time, title, and description fields must not be empty.</li>
<li>Start and End Times:</li>
  <ul>
   <li>Start time processing is flexible.  You can specify either  YYYY-MM-DD HH:MM format, or many formats as defined by the strtotime function, including relative times.  If a relative time is supplied it is assumed to be relative to the current time.</li>
   <li>End time processing is flexible, and may be empty.  You can specify either an absolute time (in the same format as the start time) or a relative time.  If a relative time is specified, it is assumed to be relative to the start time.   i.e: &quot;+4 hours&quot; would indicate 4 hours from the start time column.</li>
   <li>If the end time colume is the string &quot;All day&quot; <em>(case insensitive)</em> it will assume an all day event from the start time.</li>
   <li>If the end time column is empty, then no end time value will be created in the database.</li>
  </ul>
</li>
<li>Categories
  <ul>
   <li>If specified, the category column can contain a list (separated by ;) of category names for which the event should belong.</li>
   <li>Category names are case sensitive.</li>
   <li>Categories are not created if they do not exist.</li>
  </ul>
</li>
<li>Custom Fields:
  <ul>
    <li>Custom field names (even in the first line that determines the field mapping) are case sensitive.</li>
    <li>Cutom fields are not created if specified in the CSV file.  Unknown custom field columns will be ignored.</li>
    <li>Custom fields of type &quot;file&quot; cannot be imported.  The entire import operation will fail.</li>
  </ul>
  </li>
  </ul>
</li>
<li>A sample csv file exists in the modules source code directory.</li>
</ul>';
$lang['prompt_csv_file'] = 'S&eacute;lectionner le fichier d&#039;importation';
$lang['delete'] = 'Effacer';
$lang['cd_company'] = 'Company Directory Company';
$lang['dflt_urlprefix'] = 'Pr&eacute;fixe d&#039;URL par d&eacute;faut pour &quot;pretty URLS&quot;';
$lang['dflt_alldayevent'] = 'Les nouveaux &eacute;v&eacute;nements sont des &eacute;v&eacute;nements &quot;jour entier (all day)&quot; par d&eacute;faut';
$lang['dflt_starttime'] = 'Heure de d&eacute;but par d&eacute;faut pour les nouveaux &eacute;v&eacute;nements';
$lang['info_dflt_starttime'] = '<em>(S&#039;applique uniquement si les nouveaux &eacute;v&eacute;nements ne sont pas des &eacute;v&eacute;nements &quot;jour entier / All Day&quot;.)</em>';
$lang['search_type'] = 'Type de recherche';
$lang['search_any'] = 'renvoie le r&eacute;sultat sur n&#039;importe lequel des mots recherch&eacute;s';
$lang['search_all'] = 'renvoie le r&eacute;sultat de recherche sur tous les mots recherch&eacute;s';
$lang['info_customfields'] = '<span style=&quot;color: red;&quot;>Note :</span> les recherches ne peuvent &ecirc;tre utilis&eacute;es que dans les champs de texte. Cocher les autres types de champ n&#039;aura aucun effet sur la recherche.';
$lang['searchable'] = 'Utilisable comme crit&egrave;re de recherche';
$lang['help_param_editeventtemplate'] = 'Applicable uniquement pour l&#039;action Mes &Eacute;v&eacute;nements, ce param&egrave;tre permet de sp&eacute;cifier un autre gabarit d&#039;&eacute;dition d&#039;&eacute;v&eacute;nement (invoqu&eacute; lorsque l&#039;utilisateur cr&eacute;e ou &eacute;dite un &eacute;v&eacute;nement) que celui utilis&eacute; par d&eacute;faut.';
$lang['help_param_editpage'] = 'Applicable uniquement pour l&#039;action Mes &Eacute;v&eacute;nements, ce param&egrave;tre permet de sp&eacute;cifier une autre page pour le formulaire d&#039;&eacute;dition.';
$lang['help_param_myeventstemplate'] = 'Applicable uniquement pour l&#039;action Mes &Eacute;v&eacute;nements, ce param&egrave;tre permet de sp&eacute;cifier un autre gabarit que celui utilis&eacute; par d&eacute;faut.';
$lang['cal_edit_event'] = 'Editer un &eacute;v&eacute;nement du calendrier';
$lang['error_dberror'] = 'Erreur de base de donn&eacute;es';
$lang['submit'] = 'Soumettre';
$lang['info_sysdflt_editevent_template'] = 'Gabarit syst&egrave;me pour &amp;quot;Editer un &eacute;v&eacute;nement&amp;quot;';
$lang['info_sysdflt_myevents_template'] = 'Gabarit syst&egrave;me pour &amp;quot;Mes &Eacute;v&eacute;nements&amp;quot;';
$lang['prompt_feedit_group'] = 'Les membres de ce groupe FEU peuvent ajouter des &eacute;v&eacute;nements';
$lang['prompt_feedit_page'] = 'Page par d&eacute;faut pour le formulaire d&#039;&eacute;dition en frontend.';
$lang['none'] = 'Aucun';
$lang['owner'] = 'Propri&eacute;taire';
$lang['cal_editevent_templates'] = 'Gabarits de formulaire d&#039;&eacute;dition d&#039;&eacute;v&eacute;nement';
$lang['info_editevent_template_tab'] = 'La liste des gabarits disponibles pour le formulaire d&#039;&eacute;dition d&#039;&eacute;v&eacute;nement';
$lang['editeventtemplate_addedit'] = 'Ajouter/Editer un gabarit de formulaire d&#039;&eacute;dition d&#039;&eacute;v&eacute;nement';
$lang['cal_myevents_templates'] = 'Gabarits de liste &#039;Mes &Eacute;v&eacute;nements&#039;';
$lang['info_myevents_template_tab'] = 'La liste des gabarits disponibles pour afficher une liste d&#039;&eacute;v&eacute;nements d&#039;utilisateur';
$lang['myeventstemplate_addedit'] = 'Ajouter/Editer un gabarit de rapport de &quot;Mes Ev&eacute;nements&quot;';
$lang['areyousure_removeconflicting'] = 'Cette action va supprimer tous les &eacute;v&eacute;nements en conflit avec des &eacute;v&eacute;nements qui ne peuvent se chevaucher. &Ecirc;tes-vous s&ucirc;r de vouloir faire &ccedil;a ?';
$lang['filter_conflicting'] = 'Filtre des &eacute;v&eacute;nements en conflit';
$lang['overlap_action_remove'] = 'Effacer silencieusement des &eacute;v&eacute;nements en conflit';
$lang['overlap_action_error'] = 'Affiche une erreur';
$lang['prompt_overlap_action'] = 'Ce qu&#039;il devrait se passer quand un conflit est d&eacute;tect&eacute; &agrave; l&#039;&eacute;dition ou &agrave; l&#039;ajout d&#039;un &eacute;v&eacute;nement';
$lang['error_event_conflict'] = 'Les valeurs sp&eacute;cifi&eacute;es de l&#039;&eacute;v&eacute;nement chevauchent un &eacute;v&eacute;nement existant qui n&#039;autorise pas le conflit.';
$lang['cal_info_overlap'] = 'S&#039;applique seulement aux &eacute;v&eacute;nements comportant une heure de fin (ou les &eacute;v&eacute;nements de tous les jours)';
$lang['cal_overlap'] = 'Autorise les nouveaux &eacute;v&eacute;nements &agrave; chevaucher celui-l&agrave;';
$lang['prompt_overlap_policy'] = 'Politique de chevauchement d&#039;&eacute;v&eacute;nement';
$lang['policy_all'] = 'Tous les &eacute;v&eacute;nements peuvent se chevaucher';
$lang['policy_none'] = 'Aucun &eacute;v&eacute;nement ne peut se chevaucher';
$lang['policy_individual'] = 'Choix pour chaque &eacute;v&eacute;nement';
$lang['lbl_back'] = 'Retour';
$lang['lbl_templates'] = 'Gabarits';
$lang['textarea'] = 'Zone de Texte (Textarea)';
$lang['error_calendar_incompatible'] = 'Nous avons d&eacute;tect&eacute; que le module Calendar est d&eacute;j&agrave; install&eacute;. Ce module n&#039;est pas compatible avec le module Calendar et ne peut pas coexister avec lui sur la m&ecirc;me installation. Veuillez d&eacute;sinstaller le module Calendar';
$lang['error_event_not_found'] = 'Soit l&#039;event_id n&#039;est pas pr&eacute;sent en base de donn&eacute;es, soit il y a plus d&#039;un &eacute;v&eacute;nement poss&eacute;dant cet id ! (%d)';
$lang['first_page'] = '<<';
$lang['prev_page'] = '<';
$lang['next_page'] = '>';
$lang['last_page'] = '>>';
$lang['page_of'] = 'Page %d sur %d';
$lang['search_results'] = 'R&eacute;sultats de la Recherche du Calendrier';
$lang['search_words'] = 'Mots Recherch&eacute;s';
$lang['no_results_found'] = 'Aucun r&eacute;sultat trouv&eacute; correspondant &agrave; la demande';
$lang['frequency'] = 'Fr&eacute;quence';
$lang['specified_date'] = 'Utiliser la date sp&eacute;cifi&eacute;e';
$lang['first_sunday'] = 'Premier dimanche du mois';
$lang['first_monday'] = 'Premier lundi du mois';
$lang['first_tuesday'] = 'Premier mardi du mois';
$lang['first_wednesday'] = 'Premier mercredi du mois';
$lang['first_thursday'] = 'Premier jeudi du mois';
$lang['first_friday'] = 'Premier vendredi du mois';
$lang['first_saturday'] = 'Premier samedi du mois';
$lang['second_sunday'] = 'Deuxi&egrave;me dimanche du mois';
$lang['second_monday'] = 'Deuxi&egrave;me lundi du mois';
$lang['second_tuesday'] = 'Deuxi&egrave;me mardi du mois';
$lang['second_wednesday'] = 'Deuxi&egrave;me mercredi du mois';
$lang['second_thursday'] = 'Deuxi&egrave;me jeudi du mois';
$lang['second_friday'] = 'Deuxi&egrave;me vendredi du mois';
$lang['second_saturday'] = 'Deuxi&egrave;me samedi du mois';
$lang['third_sunday'] = 'Troisi&egrave;me dimanche du mois';
$lang['third_monday'] = 'Troisi&egrave;me lundi du mois';
$lang['third_tuesday'] = 'Troisi&egrave;me mardi du mois';
$lang['third_wednesday'] = 'Troisi&egrave;me mercredi du mois';
$lang['third_thursday'] = 'Troisi&egrave;me jeudi du mois';
$lang['third_friday'] = 'Troisi&egrave;me vendredi du mois';
$lang['third_saturday'] = 'Troisi&egrave;me samedi du mois';
$lang['fourth_sunday'] = 'Quatri&egrave;me dimanche du mois';
$lang['fourth_monday'] = 'Quatri&egrave;me lundi du mois';
$lang['fourth_tuesday'] = 'Quatri&egrave;me mardi du mois';
$lang['fourth_wednesday'] = 'Quatri&egrave;me mercredi du mois';
$lang['fourth_thursday'] = 'Quatri&egrave;me jeudi du mois';
$lang['fourth_friday'] = 'Quatri&egrave;me vendredi du mois';
$lang['fourth_saturday'] = 'Quatri&egrave;me samedi du mois';
$lang['last_sunday'] = 'Dernier dimanche du mois';
$lang['last_monday'] = 'Dernier lundi du mois';
$lang['last_tuesday'] = 'Dernier mardi du mois';
$lang['last_wednesday'] = 'Dernier mercredi du mois';
$lang['last_thursday'] = 'Dernier jeudi du mois';
$lang['last_friday'] = 'Dernier vendredi du mois';
$lang['last_saturday'] = 'Dernier samedi du mois';
$lang['error_invalid_recur_monthly_freq'] = 'Fr&eacute;quence invalide... vous ne pouvez sp&eacute;cifier ET la date ET d&#039;autres valeurs';
$lang['searchresulttemplate_addedit'] = 'Ajouter/Modifier un gabarit pour les r&eacute;sultats de recherche';
$lang['info_searchresult_template_tab'] = 'La liste des gabarits qui sont disponibles pour l&#039;affichage des r&eacute;sultats de la recherche';
$lang['info_sysdflt_searchresult_template'] = 'Gabarit de formulaire de r&eacute;sultat par d&eacute;faut';
$lang['cal_search_result_templates'] = 'Gabarit pour les r&eacute;sultats de recherche';
$lang['error_query_failed'] = 'R&ecirc;quete en base &eacute;chou&eacute;e';
$lang['error_search_invalid_dates'] = 'Les dates indiqu&eacute;es pour la recherche sont invalides';
$lang['text'] = 'Texte';
$lang['search'] = 'Recherche';
$lang['category'] = 'Cat&eacute;gorie';
$lang['info_sysdflt_search_template'] = 'Gabarit de formulaire de recherche par d&eacute;faut';
$lang['searchtemplate_addedit'] = 'Ajouter/Modifier un gabarit de formulaire de recherche';
$lang['info_search_template_tab'] = 'La liste des gabarits qui sont disponibles pour le formulaire de recherche';
$lang['cal_search_form_templates'] = 'Gabarits de formulaire de recherche';
$lang['max'] = 'max ';
$lang['times'] = 'fois';
$lang['on'] = 'on ';
$lang['areyousure_uninstall'] = '&Ecirc;tes-vous s&ucirc;r de vouloir faire ceci ? Si vous poursuivez, vous aller effacer de mani&egrave;re d&eacute;finitive toutes les donn&eacute;es associ&eacute;es &agrave; ce module.';
$lang['post_uninstall'] = 'Le module Calendrier (CG) a &eacute;t&eacute; d&eacute;sinstall&eacute; et tous les &eacute;v&eacute;nements et les informations de gabarit associ&eacute;s &agrave; ce module ont &eacute;t&eacute; supprim&eacute;s.';
$lang['fieldupdated'] = 'Champ mis &agrave; jour.';
$lang['every'] = 'Tous les';
$lang['or'] = 'ou';
$lang['update_children'] = 'Mettre &agrave; jour les sous-&eacute;v&eacute;nement associ&eacute;s';
$lang['error_nocategory'] = 'Vous devez s&eacute;lectionner au moins une cat&eacute;gorie.';
$lang['error_nothingselected'] = 'Rien n&#039;a &eacute;t&eacute; s&eacute;lectionn&eacute; pour l&#039;effacement.';
$lang['error_eventoverlap'] = 'Vos param&egrave;tres de r&eacute;p&eacute;tition d&#039;&eacute;v&eacute;nement engendrent un chevauchement d&#039;&eacute;v&eacute;nements.';
$lang['recurs'] = 'R&eacute;p&eacute;titions';
$lang['error_invalid_dates'] = 'Une ou plusieurs valeurs entr&eacute;es pour la date sont incorrectes';
$lang['sunday'] = 'Dimanche';
$lang['monday'] = 'Lundi';
$lang['tuesday'] = 'Mardi';
$lang['wednesday'] = 'Mercredi';
$lang['thursday'] = 'Jeudi';
$lang['friday'] = 'Vendredi';
$lang['saturday'] = 'Samedi';
$lang['abbr_sunday'] = 'Di';
$lang['abbr_monday'] = 'Lu';
$lang['abbr_tuesday'] = 'Ma';
$lang['abbr_wednesday'] = 'Me';
$lang['abbr_thursday'] = 'Je';
$lang['abbr_friday'] = 'Ve';
$lang['abbr_saturday'] = 'Sa ';
$lang['weekdays'] = 'Jours de la semaine';
$lang['plural_daily'] = 'Jours';
$lang['plural_weekly'] = 'Semaines';
$lang['plural_monthly'] = 'Mois';
$lang['plural_yearly'] = 'Ann&eacute;es';
$lang['no'] = 'Non';
$lang['daily'] = 'Chaque jour';
$lang['weekly'] = 'Chaque semaine';
$lang['monthly'] = 'Chaque mois';
$lang['yearly'] = 'Chaque ann&eacute;e';
$lang['interval'] = 'R&eacute;p&eacute;ter chaque';
$lang['cal_recur_details'] = 'D&eacute;tails des &eacute;v&eacute;nements r&eacute;p&eacute;titifs';
$lang['unlimited'] = 'Illimit&eacute;';
$lang['max_recur_events'] = 'Nombre maximum de sous-&eacute;v&eacute;nements';
$lang['use_to_date'] = 'Sp&eacute;cifier une date de fin diff&eacute;rente ?';
$lang['cancel'] = 'Annuler';
$lang['show_child_events'] = 'Afficher les sous-&eacute;v&eacute;nements <em>(peut causer un affichage tr&egrave;s long)</em>';
$lang['n/a'] = 'n/a ';
$lang['recurs_until'] = 'R&eacute;p&eacute;tition jusqu&#039;&agrave;';
$lang['parent'] = 'Parent ';
$lang['recur_period'] = 'P&eacute;riode de r&eacute;p&eacute;tition';
$lang['filter'] = 'Filtre';
$lang['start_date'] = 'Date de d&eacute;but';
$lang['end_date'] = 'Date de fin';
$lang['info_upcominglist_template_tab'] = 'La liste des gabarits disponibles pour afficher les &eacute;v&eacute;nements &agrave; venir';
$lang['upcominglisttemplate_addedit'] = 'Ajouter/modifier un gabarit d&#039;affichage des &eacute;v&eacute;nements &agrave; venir';
$lang['info_sysdflt_upcominglist_template'] = 'Gabarit-syst&egrave;me par d&eacute;faut pour afficher les &eacute;v&eacute;nements &agrave; venir';
$lang['info_list_template_tab'] = 'La liste des gabarits disponibles pour afficher la liste des &eacute;v&eacute;nements';
$lang['listtemplate_addedit'] = 'Ajouter/modifier un gabarit pour afficher la liste des &eacute;v&eacute;nements';
$lang['info_sysdflt_list_template'] = 'Gabarit-syst&egrave;me par d&eacute;faut pour afficher la liste des &eacute;v&eacute;nements';
$lang['info_event_template_tab'] = 'La liste des gabarits disponibles pour afficher un &eacute;v&eacute;nement en d&eacute;tail';
$lang['eventtemplate_addedit'] = 'Ajouter/modifier un gabarit d&#039;affichage d&#039;un &eacute;v&eacute;nement en d&eacute;tail';
$lang['info_sysdflt_event_template'] = 'Gabarit-syst&egrave;me par d&eacute;faut pour afficher un &eacute;v&eacute;nements en d&eacute;tail';
$lang['info_calendar_template_tab'] = 'La liste des gabarits disponibles pour afficher un calendrier';
$lang['calendartemplate_addedit'] = 'Ajouter/modifier un gabarit d&#039;affichage d&#039;un calendrier';
$lang['info_sysdflt_calendar_template'] = 'Gabarit-syst&egrave;me par d&eacute;faut pour afficher un calendrier';
$lang['info_sysdflt_template'] = 'Ce formulaire d&eacute;finit le gabarit qui sera utilis&eacute; lorsque vous cliquerez sur &quot;Nouveau gabarit&quot; dans l&#039;onglet appropri&eacute;. Modifier son contenu n&#039;a pas d&#039;effet imm&eacute;diat sur les affichages invoquant des gabarits existants, mais s&#039;appliquera aux prochains gabarits cr&eacute;&eacute;s.';
$lang['eventdesc-EventAdded'] = 'Appel&eacute; apr&egrave;s l&#039;ajout d&#039;un &eacute;v&eacute;nement de calendrier';
$lang['eventdesc-EventEdited'] = 'Appel&eacute; apr&egrave;s l&#039;&eacute;dition d&#039;un &eacute;v&eacute;nement de calendrier existant';
$lang['eventdesc-EventDeleted'] = 'Appel&eacute; apr&egrave;s qu&#039;un &eacute;v&eacute;nement ait &eacute;t&eacute; supprim&eacute;';
$lang['eventdesc-CategoryAdded'] = 'Appel&eacute; apr&egrave;s la cr&eacute;ation d&#039;une cat&eacute;gorie';
$lang['eventdesc-CategoryEdited'] = 'Appel&eacute; apr&egrave;s l&#039;&eacute;dition d&#039;une cat&eacute;gorie';
$lang['eventdesc-CategoryDeleted'] = 'Appel&eacute; apr&egrave;s qu&#039;une cat&eacute;gorie aie &eacute;t&eacute; supprim&eacute;e';
$lang['eventhelp-EventAdded'] = '<p>Envoy&eacute; quand un &eacute;v&eacute;nement de calendrier est ajout&eacute;.</p>
<h4>Param&egrave;tres</h4>
<ul>
<li>\&quot;event_title\&quot; - Titre de l&#039;&eacute;v&eacute;nement</li>
<li>\&quot;event_summary\&quot; - Texte du sommaire</li>
<li>\&quot;event_details\&quot; - Description d&eacute;taill&eacute;e</li>
<li>\&quot;event_date_start\&quot; - Date et heure du d&eacute;but de l&#039;&eacute;v&eacute;nement</li>
<li>\&quot;event_date_end\&quot; - Date et heure de la fin de l&#039;&eacute;v&eacute;nement</li>
<li>\&quot;event_created_by\&quot; - Le userid de l&#039;auteur</li>
<li>\&quot;event_id\&quot; - L&#039;id de l&#039;&eacute;v&eacute;nement</li>
</ul>
';
$lang['eventhelp-EventEdited'] = '<p>Envoy&eacute; quand un &eacute;v&eacute;nement de calendrier est &eacute;dit&eacute;.</p>
<h4>Param&egrave;tres</h4>
<ul>
<li>\&quot;event_title\&quot; - Titre de l&#039;&eacute;v&eacute;nement</li>
<li>\&quot;event_summary\&quot; - Texte du sommaire</li>
<li>\&quot;event_details\&quot; - Description d&eacute;taill&eacute;e</li>
<li>\&quot;event_date_start\&quot; - Date et heure du d&eacute;but de l&#039;&eacute;v&eacute;nement</li>
<li>\&quot;event_date_end\&quot; - Date et heure de la fin de l&#039;&eacute;v&eacute;nement</li>
<li>\&quot;event_created_by\&quot; - Le userid de l&#039;auteur</li>
<li>\&quot;event_id\&quot; - L&#039;id de l&#039;&eacute;v&eacute;nement</li>
</ul>
';
$lang['eventhelp-EventDeleted'] = '<p>Envoy&eacute; quand un &eacute;v&eacute;nement de calendrier est supprim&eacute;.</p>
<h4>Param&egrave;tres</h4>
<ul>
<li>\&quot;event_id\&quot; - L&#039;id de l&#039;&eacute;v&eacute;nement</li>
</ul>
';
$lang['eventhelp-CategoryAdded'] = '<p>Envoy&eacute; quand une cat&eacute;gorie de calendrier est ajout&eacute;e.</p>
<h4>Param&egrave;tres</h4>
<ul>
<li>\&quot;category_id\&quot; - L&#039;id de la cat&eacute;gorie</li>
</ul>
';
$lang['eventhelp-CategoryEdited'] = '<p>Envoy&eacute; quand une cat&eacute;gorie de calendrier est &eacute;dit&eacute;e.</p>
<h4>Param&egrave;tres</h4>
<ul>
<li>\&quot;category_id\&quot; - L&#039;id de la cat&eacute;gorie</li>
<li>\&quot;category_name\&quot; - Le nom de la cat&eacute;gorie</li>
<li>\&quot;category_order\&quot; - L&#039;ordre de tri de la cat&eacute;gorie</li>
</ul>
';
$lang['eventhelp-CategoryDeleted'] = '<p>Envoy&eacute; quand une cat&eacute;gorie de calendrier est supprim&eacute;e.</p>
<h4>Param&egrave;tres</h4>
<ul>
<li>\&quot;category_id\&quot; - L&#039;id de la cat&eacute;gorie</li>
<li>\&quot;category_name\&quot; - Le nom de la cat&eacute;gorie</li>
<li>\&quot;category_order\&quot; - L&#039;ordre de tri de la cat&eacute;gorie</li>
</ul>
';
$lang['error_csv_insert'] = 'Erreur durant l&#039;importation des &eacute;v&egrave;nements depuis le css &agrave; la ligne %d';
$lang['error_csvfirstlinefldnotfound'] = 'Un champs obligatoire: %s, n&#039;a pu &ecirc;tre trouv&eacute; dans la ligne d&#039;ent&ecirc;te du fichier csv';
$lang['error_csvinvalidfirstline'] = 'Ne peut trouver une ligne d&#039;ent&ecirc;te valide dans le fichier CSV';
$lang['msg_eventadded'] = '&Eacute;v&eacute;nement ajout&eacute;';
$lang['error_noeventname'] = 'Un nom pour l&#039;&eacute;v&eacute;nement doit &ecirc;tre d&eacute;finit';
$lang['error_noupload'] = 'ERREUR&nbsp;: Aucun fichier upload&eacute; trouv&eacute;';
$lang['error_invalidfilename'] = 'ERREUR&nbsp;: Le fichier upload&eacute; ne peut pas &ecirc;tre accept&eacute;';
$lang['error_problemwithupload'] = 'ERREUR&nbsp;: Il y a eu un probl&egrave;me lors de l&#039;upload du fichier';
$lang['error_filecopyfailed'] = 'ERREUR&nbsp;: Il y a eu un probl&egrave;me lors de la copie du fichier &agrave; son emplacement final';
$lang['error_fileexists'] = 'ERREUR&nbsp;: Un fichier avec le m&ecirc;me nom existe d&eacute;j&agrave;';
$lang['error_csvfilenotfound'] = 'ERREUR&nbsp;: Impossible de trouver le fichier CSV';
$lang['error_cantopenfile'] = 'ERREUR&nbsp;: Impossible d&#039;ouvrir le fichier';
$lang['error_categoryexists'] = 'ERREUR&nbsp;: Une cat&eacute;gorie avec le nom %s existe d&eacute;j&agrave;';
$lang['cal_id'] = 'Id ';
$lang['cal_calendar'] = 'Calendrier (CG)';
$lang['cal_default_templates'] = 'Gabarits par d&eacute;faut';
$lang['cal_description'] = 'Ajout, &eacute;dition et suppression d&#039;&eacute;v&eacute;nements';
$lang['cal_addevent'] = 'Ajouter un &eacute;v&eacute;nement';
$lang['cal_import_events'] = 'Importer des &eacute;v&eacute;nements';
$lang['cal_events'] = '&Eacute;v&eacute;nements';
$lang['cal_categories'] = 'Cat&eacute;gories';
$lang['cal_calendar_template'] = 'Gabarits de calendrier';
$lang['cal_list_template'] = 'Gabarits de liste';
$lang['cal_upcominglist_template'] = 'Gabarits d&#039;&eacute;v&eacute;nement &agrave; venir';
$lang['cal_event_template'] = 'Gabarits d&#039;&eacute;v&eacute;nement d&eacute;taill&eacute;s';
$lang['cal_settings'] = 'Param&egrave;tres';
$lang['cal_prev'] = '&laquo; Pr&eacute;c&eacute;dent';
$lang['cal_next'] = 'Suivant &raquo;';
$lang['cal_categories_updated'] = 'Cat&eacute;gories mises &agrave; jour';
$lang['cal_settings_updated'] = 'Param&egrave;tres mis &agrave; jour';
$lang['cal_add_event'] = 'Ajouter un &eacute;v&eacute;nement';
$lang['cal_edit'] = 'Editer';
$lang['cal_delete'] = 'Supprimer';
$lang['cal_areyousure'] = '&Ecirc;tes-vous s&ucirc;r de vouloir supprimer ?';
$lang['cal_update_template'] = 'Mettre &agrave; jour le gabarit';
$lang['cal_sunday'] = 'Dimanche';
$lang['cal_monday'] = 'Lundi';
$lang['cal_tuesday'] = 'Mardi';
$lang['cal_wednesday'] = 'Mercredi';
$lang['cal_thursday'] = 'Jeudi';
$lang['cal_friday'] = 'Vendredi';
$lang['cal_saturday'] = 'Samedi';
$lang['cal_sun'] = 'Dim';
$lang['cal_mon'] = 'Lun';
$lang['cal_tues'] = 'Mar';
$lang['cal_wed'] = 'Mer';
$lang['cal_thurs'] = 'Jeu';
$lang['cal_fri'] = 'Ven';
$lang['cal_sat'] = 'Sam';
$lang['cal_january'] = 'Janvier';
$lang['cal_february'] = 'F&eacute;vrier';
$lang['cal_march'] = 'Mars';
$lang['cal_april'] = 'Avril';
$lang['cal_may'] = 'Mai';
$lang['cal_june'] = 'Juin';
$lang['cal_july'] = 'Juillet';
$lang['cal_august'] = 'Ao&ucirc;t';
$lang['cal_september'] = 'Septembre';
$lang['cal_october'] = 'Octobre';
$lang['cal_november'] = 'Novembre';
$lang['cal_december'] = 'D&eacute;cembre';
$lang['cal_add'] = 'Ajout';
$lang['cal_update'] = 'Mise &agrave; jour';
$lang['cal_event'] = '&Eacute;v&eacute;nement';
$lang['cal_date'] = 'Date ';
$lang['cal_summary'] = 'Sommaire';
$lang['cal_details'] = 'D&eacute;tails';
$lang['cal_more'] = 'plus >>';
$lang['cal_return'] = 'Retour';
$lang['cal_to'] = 'au';
$lang['cal_past_events'] = '&Eacute;v&eacute;nements pass&eacute;s';
$lang['cal_upcoming_events'] = 'Ev&eacute;nements &agrave; venir';
$lang['cal_any_category'] = 'N&#039;importe quelle cat&eacute;gorie';
$lang['cal_show_only_events_in'] = 'Afficher seulement les &eacute;v&eacute;nements de la cat&eacute;gorie';
$lang['cal_filter_by'] = 'Filtre par <em>(expression r&eacute;guli&egrave;re)</em>';
$lang['cal_go'] = 'Aller';
$lang['cal_title'] = 'Titre';
$lang['cal_fromdate'] = 'Date de d&eacute;but';
$lang['cal_todate'] = 'Date de fin';
$lang['cal_update_categories'] = 'Mise &agrave; jour des cat&eacute;gories';
$lang['cal_language'] = 'Langue';
$lang['cal_updatesettings'] = 'Mise &agrave; jour des param&egrave;tres';
$lang['cal_use_twelve_hour_clock'] = 'Utiliser le format 12 heures dans les menus d&eacute;roulants d&#039;heures ?';
$lang['cal_default_category'] = 'Cat&eacute;gorie par d&eacute;faut';
$lang['cal_update_fields'] = 'Mettre &agrave; jour les champs';
$lang['force_category'] = 'Forcer au moins une cat&eacute;gorie';
$lang['showpastyears'] = 'Nombre d&#039;ann&eacute;es autoris&eacute;es dans le pass&eacute;';
$lang['showfutureyears'] = 'Nombre d&#039;ann&eacute;es autoris&eacute;es dans le futur';
$lang['hidesummary'] = 'Le champ sommaire doit-il &ecirc;tre cach&eacute; ?';
$lang['hidecontent'] = 'Le champ contenu doit-il &ecirc;tre cach&eacute; ?';
$lang['category_reminder'] = 'Veuillez s&eacute;lectionner une ou plusieurs cat&eacute;gorie(s) pour cet &eacute;v&eacute;nement';
$lang['module_example_stylesheet'] = 'Calendrier (CG) : exemple de CSS';
$lang['error_permission'] = 'Vous avez besoin de la permission appropri&eacute;e (%s) pour acc&eacute;der &agrave; cette fonctionnalit&eacute;';
$lang['install_postmessage'] = 'Assurez-vous de d&eacute;finir la permission &quot;Modify Calendar&quot; pour les utilisateurs qui administreront les &eacute;v&eacute;nements de calendrier';
$lang['deletetagged'] = 'Supprimer les &eacute;v&eacute;nements s&eacute;lectionn&eacute;s';
$lang['confirmdeletetagged'] = '&Ecirc;tes-vous s&ucirc;r de vouloir supprimer ces &eacute;v&eacute;nements ?';
$lang['taggeddeleted'] = 'Les &eacute;v&eacute;nements s&eacute;lectionn&eacute;s ont &eacute;t&eacute; supprim&eacute;s';
$lang['templates'] = 'Gabarits';
$lang['template_help'] = 'Aide pour les gabarits';
$lang['file_templates'] = 'Gabarits sous forme de fichiers';
$lang['addtemplate'] = 'Ajouter un gabarit';
$lang['template'] = 'Gabarit';
$lang['templatenametext'] = 'Nom du gabarit';
$lang['edittemplate'] = '&Eacute;diter le gabarit';
$lang['deletetemplate'] = 'Supprimer le gabarit';
$lang['newtemplate'] = 'Nom du nouveau gabarit';
$lang['templatenameexists'] = 'Erreur&nbsp;: Un gabarit existe d&eacute;j&agrave; avec ce nom. Veuillez choisir un autre nom.';
$lang['templateimported'] = 'Le gabarit a &eacute;t&eacute; import&eacute; avec succ&egrave;s dans la base de donn&eacute;es et est maintenant install&eacute; et pr&ecirc;t &agrave; &ecirc;tre utilis&eacute;.';
$lang['view_default_stylesheet'] = 'Voir la feuille de style par d&eacute;faut';
$lang['filename'] = 'Nom de fichier';
$lang['importtemplate'] = 'Importer un gabarit';
$lang['template_deleted'] = 'Le gabarit a &eacute;t&eacute; supprim&eacute; de la base de donn&eacute;es avec succ&egrave;s';
$lang['updatetemplatesuccess'] = 'Le gabarit a &eacute;t&eacute; mis &agrave; jour avec succ&egrave;s';
$lang['updatetemplatefailure'] = 'Une erreur est survenue pendant la mise &agrave; jour du gabarit';
$lang['settingssaved'] = 'Les param&egrave;tres ont &eacute;t&eacute; sauvegard&eacute;s avec succ&egrave;s';
$lang['categorydeleted'] = 'La cat&eacute;gorie a &eacute;t&eacute; supprim&eacute;e';
$lang['categoryupdated'] = 'La cat&eacute;gorie a &eacute;t&eacute; mise &agrave; jour';
$lang['categoryadded'] = 'La cat&eacute;gorie a &eacute;t&eacute; ajout&eacute;e';
$lang['eventdeleted'] = 'L&#039;&eacute;v&eacute;nement a &eacute;t&eacute; supprim&eacute;';
$lang['eventupdated'] = 'L&#039;&eacute;v&eacute;nement a &eacute;t&eacute; mis &agrave; jour';
$lang['default_page_error'] = 'Erreur&nbsp;: Vous devez d&eacute;finir une page par d&eacute;faut pour utiliser le calendrier lorsque &quot;pretty URLs&quot; est activ&eacute;. Veuillez aller &agrave; l&#039;onglet des param&egrave;tres du calendrier et d&eacute;finir une page par d&eacute;faut.';
$lang['time_at'] = '&agrave;';
$lang['type'] = 'Type ';
$lang['name'] = 'Nom';
$lang['order'] = 'Ordre';
$lang['fieldadded'] = 'Champ ajout&eacute; avec succ&egrave;s';
$lang['fielddeleted'] = 'Champ supprim&eacute;';
$lang['fields'] = 'Champs par d&eacute;faut';
$lang['textfield'] = 'Champ texte';
$lang['uploadfield'] = 'Champ d&#039;upload de fichier';
$lang['description'] = '<p>Le module Calendrier (CG) affiche des &eacute;v&eacute;nements sur votre page. Quand le module est install&eacute;, une page d&#039;administration de calendrier est ajout&eacute;e au menu Contenu, et vous permet de g&eacute;rer vos &eacute;v&eacute;nements.</p>';
$lang['defaultcalendarpage'] = 'Page par d&eacute;faut qui contient le calendrier. Cette page doit contenir la balise smarty qui appelle le calendrier. N&eacute;cessaire si vous utilisez les &quot;pretty URLs&quot;.';
$lang['uploaddirectory'] = 'Dossier o&ugrave; les fichiers upload&eacute;s doivent &ecirc;tre stock&eacute;s';
$lang['uploadfiletypes'] = 'Types de fichiers autoris&eacute;s';
$lang['uploadunique'] = 'S&#039;assurer que les noms de fichiers soient uniques';
$lang['thumb_width'] = 'Largeur de la vignette';
$lang['thumb_height'] = 'Hauteur de la vignette';
$lang['large_width'] = 'Largeur de l&#039;image en grande taille';
$lang['large_height'] = 'Hauteur de l&#039;image en grande taille';
$lang['cal_recur_period'] = 'R&eacute;p&eacute;tition';
$lang['cal_recur_until'] = 'R&eacute;p&egrave;te jusqu&#039;&agrave;';
$lang['help_template'] = '<p><b>Affiche le nom de l&#039;auteur :</b></p>
<code>Auteur : {$event.authorname}</code>
';
$lang['cal_help'] = '		<h3>Notice:</h3>
		<p>Le module Calendrier (CG) Version 1.0  est un fork du module de Calendrier classique, mais Calendrier  (CG) n&#039;est aucunement compatible avec Calendrier.
		<h3>Que fait ce module ?</h3>
		<p>Ce module affiche des &eacute;v&eacute;nements sur vos pages. D&egrave;s que le module est install&eacute;, une page de gestion des &eacute;v&eacute;nements est ajout&eacute;e au menu d&#039;administration qui vous permettra de g&eacute;rer des &eacute;v&eacute;nements.</p>
		<h3>S&eacute;curit&eacute;</h3>
		<p>L&#039;utilisateur doit faire partie d&#039;un groupe avec la permission &#039;Modify Calendar&#039; pour pouvoir ajouter, &eacute;diter ou supprimer des &eacute;v&eacute;nements.</p>
		<h3>Comment l&#039;utiliser?</h3>
		<ol>
		  <li>Le module calendrier est utilis&eacute; en conjonction avec le tag cms_module. Veuillez vous assurer que le tag n&#039;est pas inclus dans les balises &amp;lt;pre&amp;gt; ... &amp;lt;/pre&amp;gt; Vous aurez besoin d&#039;afficher le code source pour cela. Cela ins&eacute;rera votre module dans votre gabarit ou votre page o&ugrave; vous le d&eacute;sirez, et y affichera le calendrier.  Exemple de syntaxe:<br />
		<tt>{cms_module module=&#039;CGCalendar&#039;}</tt><br />
		  <li>&Eacute;ditez la feuille de style d&#039;exemple qui a &eacute;t&eacute; ins&eacute;r&eacute;e dans la liste de vos feuilles de style.</li>
		  <li>Associez cette feuille de style au gabarit que vous utilisez pour les pages de calendrier.</li>
		</ol>
<br />
<p><b>Pour attacher la feuille de style &agrave; votre gabarit :</b></p>
<ol>
<li>Allez &agrave;  &quot;Disposition -> Gabarits&quot;.</li>
<li>Cliquez l&#039;ic&ocirc;ne CSS (Attacher une feuille de style au gabarit) &agrave; droite de votre gabarit.</li>
<li>Choisissez &quot;CGCalendrier : exemple de CSS&quot; dans le menu d&eacute;roulant.</li>
<li>Cliquez le bouton &quot;Ajouter une nouvelle feuille de style&quot;.</li>
</ol>

</p>
		<h3>Local</h3>
		<p>Notez que vous pouvez changer la langue d&#039;un calendrier affich&eacute; sur une page sp&eacute;cifique en ajoutant 
		lang=&quot;xx_XX&quot; au {cms_module module=&quot;CGCalendar&quot;}. Par exemple: {cms_module module=&quot;CGCalendar&quot; lang=&quot;de_DE&quot;}</p>

		<h3>Quels sont les param&egrave;tres possibles ?</h3>
		<table border=0 cellpadding=3 cellspacing=0>
		<tr>
			<td>action</td>
			<td>
                &quot;default&quot; - indique d&#039;utiliser l&#039;action par d&eacute;faut, fonctionne en conjonction avec le param&egrave;tre &quot;display&quot; ci-dessous.<br/>
                &quot;search&quot; - affiche un formulaire de recherche avanc&eacute;e d&#039;&eacute;v&eacute;nement du calendrier.
                &quot;myevents&quot; - affiche une liste contenant tous les &eacute;v&eacute;nements d&#039;un utilisateur et permet d&#039;ajouter, &eacute;diter ou supprimer ces &eacute;v&eacute;nements.
               &quot;addedit_event&quot; - Display a form allowing to add or edit a single event.;
		</td>
		</tr>

			<tr>
			<td>display (Affichage)</td>
			<td>Valeur accept&eacute;es:<br>
&quot;calendar&quot; (calendrier) - affiche les &eacute;v&eacute;nements pour le mois en cours dans une grille traditionnelle. Inclus les liens suivant et pr&eacute;c&eacute;dent au mois concern&eacute;.<br />
&quot;event&quot; (&eacute;v&eacute;nement) - affiche les d&eacute;tails d&#039;un &eacute;v&eacute;nement en particulier. Pour l&#039;utiliser, le param&egrave;tre event_id doit &ecirc;tre sp&eacute;cifi&eacute;.<br />
&quot;list&quot; (liste) - affiche les &eacute;v&eacute;nements pour le mois en cours sous forme de liste. Inclus les liens suivant et pr&eacute;c&eacute;dent au mois concern&eacute;.<br />
&quot;yearlist&quot; (liste annuelle) - affiche les &eacute;v&eacute;nements pour l&#039;ann&eacute;e en cours sous forme de liste. Inclus les liens suivant et pr&eacute;c&eacute;dent &agrave; l&#039;ann&eacute;e concern&eacute;e.<br />
&quot;pastlist&quot; (liste des &eacute;v&eacute;nements pass&eacute;s) - affiche tous les &eacute;v&eacute;nements pass&eacute;s. Pas de liens suivant-pr&eacute;c&eacute;dent.<br />
&quot;upcominglist&quot; (liste des &eacute;v&eacute;nements &agrave; venir) - affiche tous les &eacute;v&eacute;nements &agrave; venir. Pas de liens suivant-pr&eacute;c&eacute;dent.<br />
Valeur par d&eacute;faut : &quot;calendar&quot; <em>(optionel)</em></td>
		</tr>
		<tr>
			<td>category (Cat&eacute;gorie)</td>
			<td>Affiche seulement les &eacute;v&eacute;nements de cette cat&eacute;gorie. Laisser ce param&egrave;tre vide pour afficher tous les &eacute;v&eacute;nements. Notez que vous pouvez d&eacute;finir ici plusieurs cat&eacute;gories en les s&eacute;parant par une virgule. <em>(optionel)</em></td>
		</tr>
		<tr>
			<td>month (Mois)</td>
			<td>Affiche les &eacute;v&eacute;nements du mois sp&eacute;cifi&eacute;. Si l&#039;ann&eacute;e n&#039;est pas d&eacute;finie, l&#039;ann&eacute;e en cours est utilis&eacute;e. Cette option ne fonctionne qu&#039;avec l&#039;affichage en &quot;list&quot; ou &quot;calendar&quot;. <em>(optionel)</em></td>
		</tr>
		<tr>
			<td>year (Ann&eacute;e)</td>
			<td>Affiche les &eacute;v&eacute;nements de l&#039;ann&eacute;e sp&eacute;cifi&eacute;e. 
Cette option ne fonctionne qu&#039;avec l&#039;affichage en &quot;list&quot; ou &quot;calendar&quot;. <em>(optionel)</em></td>
		</tr>
		<tr>

 <tr>
     <td>limit</td>
     <td>Param&egrave;tre le nombre maximum d&#039;&eacute;v&egrave;nements &agrave; afficher. Cette option ne fonctionne uniquement si &quot;display&quot; est param&eacute;tr&eacute; &agrave; &quot;list&quot;, &quot;pastlist&quot; ou &quot;upcominglist&quot;. <em>(optional)</em></td>
  </tr>

		<tr>
			<td>first_day_of_week (Premier jour de la semaine)</td>
			<td>D&eacute;fini le premier jour de la semaine, en chiffre de 0 &agrave; 6 (0 = Dimanche). Valeur par d&eacute;faut : 1 (Lundi).
Cette option ne fonctionne que si &quot;display&quot; est valoris&eacute; &agrave; &quot;calendar&quot;.<em>(optionel)</em></td>
		</tr>
		<tr>
			<td>use_session</td>
			<td>Utilise des variables de session pour stocker les sp&eacute;cifications du calendrier. Ceci permet au calendrier de garder ses param&egrave;tres lors de la navigation sur plusieurs pages et lors de l&#039;affichage de plusieurs mois. Dans le formulaire de recherche, cela permet d&#039;enregistrer les param&egrave;tres de recherche jusqu&#039;&agrave; ce que le navigateur soit r&eacute;initialis&eacute;. La valeur par d&eacute;faut est &quot;false&quot; (faux). Si sp&eacute;cifi&eacute;, la valeur doit contenir un identifiant unique pour cette instance de calendrier. Cette fonction ne fonctionne que si &quot;display&quot; est valoris&eacute; &agrave; &quot;calendar&quot; ou &quot;list&quot;, ou si &quot;action&quot; est valoris&eacute; &agrave; &quot;search&quot;.<em>(optional)</em></td>
		</tr>
		<tr>
			<td>inline</td>
			<td>D&eacute;finir en 1 pour afficher tous les liens aux &eacute;v&eacute;nements en mode inline (ils remplaceront le contenu de la page).<br />
Valeur par d&eacute;faut : 0 <em>(optionel)</em></td>
		</tr>
		<tr>
			<td>reverse</td>
			<td>Valoriser &agrave; &quot;true&quot; (vrai) pour afficher les &eacute;v&eacute;nements dans l&#039;ordre chronologique inverse. Applicable aux affichages &quot;list&quot;, &quot;pastlist&quot; et &quot;upcominglist&quot;. Valeur par d&eacute;faut : &quot;false&quot; (faux). Pour l&#039;option &quot;pastlist&quot;, reverse=true est suppos&eacute;.<em>(optionel)</em></td>
		</tr>
		<tr>
			<td>detailpage=&quot;pagealias&quot;</td>
			<td>Page dans laquelle afficher les d&eacute;tails des &eacute;v&eacute;nements. Ceci peut soit &ecirc;tre soit un alias de page soit un ID de page. Utile pour permettre aux d&eacute;tails d&#039;&ecirc;tre affich&eacute;s dans un gabarit diff&eacute;rent du sommaire.<br />
Comportement par d&eacute;faut : affichage dans la page courante <em>(optionel)</em></td>
		</tr>
		<tr>
			<td>columns</td>
			<td>Le calendrier affichera uniquement une suite d&#039;&eacute;v&eacute;nements &agrave; afficher en colonnes. Valeurs possible 1 ou 2. Valeur par d&eacute;faut : 1. Impl&eacute;ment&eacute; uniquement pour les affichages &quot;upcominglist&quot; et &quot;pastlist&quot;.<em>(optionel)</em></td>
		</tr>
	  <tr>
			<td>columnstyle</td>
			<td>Si le param&egrave;tre columns=2, ce param&egrave;tre d&eacute;fini si l&#039;ordre des &eacute;v&eacute;nements en colonne doit &ecirc;tre affich&eacute; horizontalement (0) ou verticalement (1). Valeur par d&eacute;faut : 1 <em>(optionel)</em></td>
		</tr>
		<tr>
			<td>currentcolumn</td>
			<td>Si le param&egrave;tre columns=2, ce param&egrave;tre indique si le calendrier doit afficher le contenu de la colonne 1 ou 2. Valeur possible 1 ou 2.<br />
Valeur par d&eacute;faut : 1  <em>(optional)</em></td>
		</tr>
		<tr>
			<td>event_id</td>
			<td>Utilis&eacute; uniquement avec le mode d&#039;affichage &quot;event&quot; Permet d&#039;afficher les informations relatives uniquement &agrave; un &eacute;v&eacute;nement sp&eacute;cifique. </td>
		</tr>
		<tr>
			<td>limit</td>
			<td>D&eacute;fini le nombre maximal d&#039;&eacute;v&eacute;nements &agrave; afficher. Cette option ne fonctionne qu&#039;avec l&#039;affichage en &quot;list&quot;, &quot;pastlist&quot; ou &quot;upcominglist&quot; et permet de g&eacute;rer la pagination. <em>(optionel)</em></td>
		</tr>
		<tr>
			<td>calendartemplate</td>
			<td>Sp&eacute;cifie un gabarit particulier &agrave; utiliser pour l&#039;affichage en mode &quot;calendar&quot; uniquement.  <em>(optionel)</em><br />
Par exemple, si vous avez un gabarit nomm&eacute; &quot;mon-gabarit-calendrier&quot;, alors appelez le calendrier comme ceci&nbsp;:<br /><code>{cms_module module=&quot;Calendar&quot; display=&quot;calendar&quot; calendartemplate=&quot;mon-gabarit-calendrier&quot;}</code></td>
		</tr>
  <tr>
     <td>eventtemplate</td>
     <td>Utilis&eacute; en mode d&#039;affiche &quot;event&quot;. Vous pouvez &eacute;galement d&eacute;finir ce param&egrave;tre sur tous les appels au module Calendar, Ce param&egrave;tre vous permet de sp&eacute;cifier un gabarit diff&eacute;rent du gabarit par d&eacute;faut pour les &eacute;v&egrave;nements.</td>
  </tr>

		<tr>
			<td>listtemplate</td>
			<td>Sp&eacute;cifie le gabarit &agrave; utiliser pour l&#039;affichage &quot;list&quot;. <em>(optionel)</em><br/>
Par exemple, si vous avez un gabarit nomm&eacute; &quot;blog-post-month-archive-list&quot;, alors appelez le calendrier comme ceci&nbsp;:<br /><code>{cms_module module=&quot;Calendar&quot; display=&quot;list&quot; reverse=&quot;true&quot; listtemplate=&quot;blog-post-month-archive-list&quot;}</code></td>
		</tr>
		<tr>
			<td>upcominglisttemplate</td>
			<td>Sp&eacute;cifie le gabarit &agrave; utiliser pour l&#039;affichage &quot;pastlist&quot; (liste des &eacute;v&eacute;nements pass&eacute;s) ou &quot;upcominglist&quot; (liste des &eacute;v&eacute;nements &agrave; venir). <em>(optionel)</em><br />
Par exemple, si vous avez un gabarit nomm&eacute; &quot;blog-post-list-with-content&quot; et que vous d&eacute;sirez afficher les 50 derniers &eacute;v&eacute;nements de la cat&eacute;gorie &quot;g&eacute;n&eacute;rale&quot;,  alors appelez le calendrier comme ceci&nbsp;:<br /><code>{cms_module module=&quot;Calendar&quot; display=&quot;pastlist&quot; category=&quot;General&quot; upcominglisttemplate=&quot;blog-post-list-with-content&quot; limit=&quot;50&quot;}
</code></td>
		</tr>
	  <tr>
     <td>unique_only</td>
     <td>Utilis&eacute; en mode d&#039;affichage &quot;upcominglist&quot; et avec l&#039;action = &quot;search&quot;, Ce param&egrave;tre vous permet de d&eacute;finir qu&#039;un seul &eacute;v&eacute;nement d&#039;un certain type doit &ecirc;tre retourn&eacute;.
  </tr>

		</table>

		<h3>Gabarits</h3>
		<p>Les quatre types d&#039;affichage sont contr&ocirc;l&eacute;s par des gabarits qui peuvent &ecirc;tres chang&eacute;s dans l&#039;administration. Si vous voulez r&eacute;initialiser un gabarit &agrave; ses donn&eacute;es par d&eacute;faut, effacez-en compl&egrave;tement le contenu dans l&#039;administration et il sera r&eacute;initialis&eacute; lors du prochain affichage de ce calendrier sur la page.</p>

		<h3>Exemple de styles CSS</h3>
		<p>Un exemple de CSS pour afficher correctement le calendrier a &eacute;t&eacute; ajout&eacute; &agrave; la liste de vos feuilles de style. Pour le voir en action&nbsp;:
		<pre style=&quot;font-size: 12px&quot;>{cms_module module=&#039;CGCalendar&#039; table_id=&#039;big&#039;}</pre></p>

		<h3>Champs personnalis&eacute;s</h3>
		<p>Il est possible de d&eacute;finir des champs personnalis&eacute;s &agrave; associer avec chaque &eacute;v&eacute;nement au moyen de l&#039;onglet &quot;Champs&quot; dans le panneau d&#039;administration du module. Une fois qu&#039;un ou plusieurs champ(s) aient &eacute;t&eacute; d&eacute;finis, les valeurs de ce champ pour chaque &eacute;v&eacute;nement peuvent &ecirc;tre d&eacute;finies au moyen de l&#039;onglet &quot;&Eacute;v&eacute;nements&quot; dans l&#039;administration. Les valeurs de ces champs peuvent &ecirc;tre obtenue avec l&#039;utilisation d&#039;un gabarit ayant la syntaxe event.fields.fieldname. Astuce - ins&eacute;rez {debug} dans votre gabarit pour voir toutes les donn&eacute;es qui sont pass&eacute;es au gabarit.</p>

	<h3>Exemples</h3>
		<h4>Exemple autoriser les commentaires sur les &eacute;v&eacute;nements du calendrier</h4>
				<p>Installez le module Commentaires et ins&eacute;rez ceci dans votre le &quot;gabarit d&#039;&eacute;v&eacute;nement&quot; de votre calendrier&amp;nssp;:</p>
		<pre>{cms_module module=&#039;comments&#039; modulename=&#039;CGCalendar&#039; pageid=$event.event_id}</pre>
<p>Conseil : ins&eacute;rez {debug} dans votre gabarit pour voir toutes les donn&eacute;es disponibles pass&eacute;es au gabarit</p>

<h3>Support</h3>
<p>Ce module n&#039;inclu aucun support commercial. Cependant, il y a un certain nombre de ressources disponibles pour vous aider :</p>
<ul>
<li>Des discussion sur ce module peuvent &ecirc;tre trouv&eacute;es sur <a href="http://forum.cmsmadesimple.org">les forums CMS Made Simple</a>.</li>
<li>L&#039;auteur, calguy1000, peut facilement &ecirc;tre contact&eacute; sur <a href="irc://irc.freenode.net/#cms">le canal IRC relatif aux CMS</a>.</li>
<li>Enfin, vous pouvez &eacute;ventuellement contacter l&#039;auteur directement par mail.</li>  
</ul>
<h3>Copyright et Licence</h3>
<p>Copyright &amp;copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org">&amp;lt;calguy1000@cmsmadesimple.org&amp;gt;</a>. All Rights Are Reserved.</p>
<p>This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.</p>
<p>However, as a special exception to the GPL, this software is distributed
as an addon module to CMS Made Simple.  You may not use this software
in any Non GPL version of CMS Made simple, or in any version of CMS
Made simple that does not indicate clearly and obviously in its admin 
section that the site was built with CMS Made simple.</p>
<p>This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>
';
$lang['utma'] = '156861353.748041509.1335632272.1335632272.1335774814.2';
$lang['utmz'] = '156861353.1335632272.1.1.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353.1.10.1335774814';
?>